summaryrefslogtreecommitdiffstats
path: root/chrome/browser/history/visitsegment_database.h
diff options
context:
space:
mode:
authorjcampan@chromium.org <jcampan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-04-13 19:00:29 +0000
committerjcampan@chromium.org <jcampan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-04-13 19:00:29 +0000
commit34cdd0557b61c9c98aa0510cadfcd814a8156b44 (patch)
treefc5ee6c4e81b184e5259a23ed1957528bf034615 /chrome/browser/history/visitsegment_database.h
parent5c65e10ad600bf4786f9eb8f6f30872bc61231e3 (diff)
downloadchromium_src-34cdd0557b61c9c98aa0510cadfcd814a8156b44.zip
chromium_src-34cdd0557b61c9c98aa0510cadfcd814a8156b44.tar.gz
chromium_src-34cdd0557b61c9c98aa0510cadfcd814a8156b44.tar.bz2
This CL adds some UI to remove most-visited thumbnails from the New Tab Page.
The URL of removed thumbnails is added to a blacklist, which is a user pref. I had to modify the VisitSegmentDatabase::QuerySegmentUsage not to return a fixed number of items, as now we may filter the ones we get back. Note: this adds between 20 and 30ms to the first NTP load on my machine (a 3 to 5% increase). BUG=685 TEST=Open the NTP. Click the 'Edit thumbnails' link. Remove some thumbnails. Press Done. Edit again, use the "Restore removed" link. Review URL: http://codereview.chromium.org/67037 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@13611 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/history/visitsegment_database.h')
-rw-r--r--chrome/browser/history/visitsegment_database.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/chrome/browser/history/visitsegment_database.h b/chrome/browser/history/visitsegment_database.h
index 2f2bbb2..0eb0a36f 100644
--- a/chrome/browser/history/visitsegment_database.h
+++ b/chrome/browser/history/visitsegment_database.h
@@ -49,8 +49,10 @@ class VisitSegmentDatabase {
int amount);
// Compute the segment usage since |from_time| using the provided aggregator.
// A PageUsageData is added in |result| for the nine highest-scored segments.
void QuerySegmentUsage(const base::Time& from_time,
+ int max_result_count,
std::vector<PageUsageData*>* result);
// Delete all the segment usage data which is older than the provided time
@@ -49,8 +49,10 @@ class VisitSegmentDatabase {
int amount);
// Compute the segment usage since |from_time| using the provided aggregator.
- // A PageUsageData is added in |result| for the nine highest-scored segments.
+ // A PageUsageData is added in |result| for the highest-scored segments up to
+ // |max_result_count|.
void QuerySegmentUsage(const base::Time& from_time,